## $Id: interfaces.py 8053 2012-04-06 16:01:57Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""Customized interfaces of the university application package.
"""

from zope import schema
from waeup.kofa.applicants.interfaces import (
    IApplicantBaseData,
    AppCatCertificateSource, CertificateSource)
from waeup.kofa.schoolgrades import ResultEntryField
from waeup.kofa.interfaces import SimpleKofaVocabulary
from waeup.uniben.interfaces import MessageFactory as _

high_qual = SimpleKofaVocabulary(
    ('National Certificate of Education','nce'),
    ('Pre Degree Programme','pre'),
    ('Diploma Programme','dip'),
    ('Ordinary National Diploma','ond'),
    ('Bachelors Degree','bd'),
    ('Masters Degree','md'),
    ('Professional Qualification','pq'),
    ('Other Certification','oc'),
    ('Higher National Diploma','hnd'),
    ('NCE AL OTH','nce_al_oth'),
    ('National Defence Academy','nda'),
    ('Awaiting Results','a_rslt'),
    ('RMC','rmc'),
    )

high_grade = SimpleKofaVocabulary(
    ('Upper Credit','upper_credit'),
    ('Distinction','distinction'),
    ('Credit','credit'),
    ('Merit','merit'),
    ('Lower Credit','lower_credit'),
    ('First Class','first_class'),
    ('Second Class Upper','second_class_upper'),
    ('Second Class Lower','second_class_lower'),
    ('Third Class','third_class'),
    ('Pass','pass'),
    ('Awaiting Results','a_rslt'),
    ('A Levels','al'),
    )

exam_types = SimpleKofaVocabulary(
    ('SSCE','ssce'),
    ('WAEC','waec'),
    ('GCE O\' LEVEL','gce_o_level'),
    ('TC II','tc_ii'),
    ('RSA','rsa'),
    ('NABTEB','nabteb'),
    ('NECO','neco'),
    ('ACE','ace'),
    ('GCE A\' LEVEL','gce_a_level'),
    ('IGCSE','igcse'),
    )

class IUGApplicant(IApplicantBaseData):
    """An undergraduate applicant.

    """

class IPGApplicant(IApplicantBaseData):
    """A postgraduate applicant.

    """

    perm_address = schema.Text(
        title = _(u'Permanent Address'),
        required = False,
        )
    course1 = schema.Choice(
        title = _(u'1st Choice Course of Study'),
        source = AppCatCertificateSource(),
        required = True,
        )
    course2 = schema.Choice(
        title = _(u'2nd Choice Course of Study'),
        source = AppCatCertificateSource(),
        required = False,
        )
    hq_type = schema.Choice(
        title = _(u'Qualification Obtained'),
        required = False,
        readonly = False,
        vocabulary = high_qual,
        )
    hq_matric_no = schema.TextLine(
        title = _(u'Former Matric Number'),
        required = False,
        readonly = False,
        )
    hq_degree = schema.Choice(
        title = _(u'Class of Degree'),
        required = False,
        readonly = False,
        vocabulary = high_grade,
        )
    hq_school = schema.TextLine(
        title = _(u'Institution Attended'),
        required = False,
        readonly = False,
        )
    hq_session = schema.TextLine(
        title = _(u'Years Attended'),
        required = False,
        readonly = False,
        )
    hq_disc = schema.TextLine(
        title = _(u'Discipline'),
        required = False,
        readonly = False,
        )
    pp_school = schema.Choice(
        title = _(u'Qualification Obtained'),
        required = False,
        readonly = False,
        vocabulary = exam_types,
        )
    employer = schema.TextLine(
        title = _(u'Employer'),
        required = False,
        readonly = False,
        )
    emp_position = schema.TextLine(
        title = _(u'Employer Position'),
        required = False,
        readonly = False,
        )
    emp_start = schema.Date(
        title = _(u'Start Date'),
        required = False,
        readonly = False,
        )
    emp_end = schema.Date(
        title = _(u'End Date'),
        required = False,
        readonly = False,
        )
    emp_reason = schema.TextLine(
        title = _(u'Reason for Leaving'),
        required = False,
        readonly = False,
        )
    employer2 = schema.TextLine(
        title = _(u'2nd Employer'),
        required = False,
        readonly = False,
        )
    emp2_position = schema.TextLine(
        title = _(u'2nd Employer Position'),
        required = False,
        readonly = False,
        )
    emp2_start = schema.Date(
        title = _(u'Start Date'),
        required = False,
        readonly = False,
        )
    emp2_end = schema.Date(
        title = _(u'End Date'),
        required = False,
        readonly = False,
        )
    emp2_reason = schema.TextLine(
        title = _(u'Reason for Leaving'),
        required = False,
        readonly = False,
        )
    notice = schema.Text(
        title = _(u'Notice'),
        required = False,
        readonly = False,
        )
    screening_venue = schema.TextLine(
        title = _(u'Screening Venue'),
        required = False,
        readonly = False,
        )
    screening_score = schema.Int(
        title = _(u'Screening Score'),
        required = False,
        readonly = False,
        )
    course_admitted = schema.Choice(
        title = _(u'Admitted Course of Study'),
        source = CertificateSource(),
        required = False,
        readonly = False,
        )


IPGApplicant[
    'student_id'].order =  IPGApplicant['notice'].order

class IApplicant(IUGApplicant,IPGApplicant):
    """An interface for both types of applicants.

    """

    def loggerInfo(ob_class, comment):
        """Adds an INFO message to the log file
        """

    def createStudent():
        """Create a student object from applicatnt data
        and copy applicant object.
        """

class IUGApplicantEdit(IUGApplicant):
    """An undergraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """

class IPGApplicantEdit(IPGApplicant):
    """A postgraduate applicant interface for editing.

    Here we can repeat the fields from base data and set the
    `required` and `readonly` attributes to True to further restrict
    the data access. Or we can allow only certain certificates to be
    selected by choosing the appropriate source.

    We cannot omit fields here. This has to be done in the
    respective form page.
    """
